==> 1.0.1-dev.tar.gz: lib/src/model/material_palette.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutterx_material_tool/src/model/colors.dart';
import 'package:flutterx_material_tool/src/utils.dart';

typedef ResultMap<T> = T Function(Color primary, Map<int, Color> swatch);

@immutable
class MaterialPalette<T> {
  final List<int> shades;
  final List<List<LABColor>> palettes;
  final int primaryIndex;
  final ResultMap _mapResult;

  const MaterialPalette(this.shades, this.primaryIndex, this.palettes, this._mapResult);

  factory MaterialPalette.fromSwatches(
    List<int> shades,
    int primaryIndex,
    List<ColorSwatch> swatches,
    ResultMap mapResult,
  ) =>
      MaterialPalette(
        shades,
        primaryIndex,
        swatches
            .map((swatch) =>
                shades.map((shade) => RGBColor.fromColor(swatch[shade]!).toLABColor()).toList(growable: false))
            .toList(growable: false),
        mapResult,
      );

  T mapResult(List<Color> colors) {
    final primary = colors[primaryIndex];
    final swatch = Map<int, Color>.fromEntries(colors.mapIndexed((index, item) => MapEntry(shades[index], item)));
    return _mapResult(primary, swatch);
  }

  static final accent = MaterialPalette<MaterialAccentColor>.fromSwatches(
    const [100, 200, 400, 700],
    1,
    const <MaterialAccentColor>[
      Colors.redAccent,
      Colors.pinkAccent,
      Colors.purpleAccent,
      Colors.deepPurpleAccent,
      Colors.indigoAccent,
      Colors.blueAccent,
      Colors.lightBlueAccent,
      Colors.cyanAccent,
      Colors.tealAccent,
      Colors.greenAccent,
      Colors.lightGreenAccent,
      Colors.limeAccent,
      Colors.yellowAccent,
      Colors.amberAccent,
      Colors.orangeAccent,
      Colors.deepOrangeAccent,
    ],
    (primary, swatch) => MaterialAccentColor(primary.value, swatch),
  );
  static final primary = MaterialPalette<MaterialColor>.fromSwatches(
    const [50, 100, 200, 300, 400, 500, 600, 700, 800, 900],
    5,
    const <MaterialColor>[
      Colors.red,
      Colors.pink,
      Colors.purple,
      Colors.deepPurple,
      Colors.indigo,
      Colors.blue,
      Colors.lightBlue,
      Colors.cyan,
      Colors.teal,
      Colors.green,
      Colors.lightGreen,
      Colors.lime,
      Colors.yellow,
      Colors.amber,
      Colors.orange,
      Colors.deepOrange,
      Colors.brown,
      Colors.grey,
      Colors.blueGrey,
    ],
    (primary, swatch) => MaterialColor(primary.value, swatch),
  );
}

==> 1.0.2-dev.tar.gz: lib/src/model/material_palette.dart <==
import 'package:flutter/foundation.dart';
import 'package:flutter/material.dart';
import 'package:flutterx_material_tool/src/model/colors.dart';
import 'package:flutterx_material_tool/src/model/palette_data.dart';
import 'package:flutterx_material_tool/src/utils.dart';

typedef ResultMap<T> = T Function(Color primary, Map<int, Color> swatch);

@immutable
class MaterialPalette<T> {
  final List<int> shades;
  final List<List<LABColor>> palettes;
  final int primaryIndex;
  final ResultMap _mapResult;

  const MaterialPalette(this.shades, this.primaryIndex, this.palettes, this._mapResult);

  factory MaterialPalette.fromSwatches(
    List<int> shades,
    int primaryIndex,
    List<ColorSwatch> swatches,
    ResultMap mapResult,
  ) =>
      MaterialPalette(
        shades,
        primaryIndex,
        swatches
            .map((swatch) =>
                shades.map((shade) => RGBColor.fromColor(swatch[shade]!).toLABColor()).toList(growable: false))
            .toList(growable: false),
        mapResult,
      );

  T map(PaletteData data) {
    final primary = data[primaryIndex];
    final swatch = Map<int, Color>.fromEntries(data.swatch.mapIndexed((index, item) => MapEntry(shades[index], item)));
    return _mapResult(primary, swatch);
  }

  PaletteData<T> generate(RGBColor input) => PaletteData<T>.fromColor(input, this);

  PaletteData<T> generateComplementary(RGBColor input) => PaletteData<T>.fromColor(input.shift(180), this);

  PaletteData<T> generateAnalogousA(RGBColor input) => PaletteData<T>.fromColor(input.shift(-30), this);

  PaletteData<T> generateAnalogousB(RGBColor input) => PaletteData<T>.fromColor(input.shift(30), this);

  PaletteData<T> generateTriadicA(RGBColor input) => PaletteData<T>.fromColor(input.shift(60), this);

  PaletteData<T> generateTriadicB(RGBColor input) => PaletteData<T>.fromColor(input.shift(120), this);

  static final accent = MaterialPalette<MaterialAccentColor>.fromSwatches(
    const [100, 200, 400, 700],
    1,
    const <MaterialAccentColor>[
      Colors.redAccent,
      Colors.pinkAccent,
      Colors.purpleAccent,
      Colors.deepPurpleAccent,
      Colors.indigoAccent,
      Colors.blueAccent,
      Colors.lightBlueAccent,
      Colors.cyanAccent,
      Colors.tealAccent,
      Colors.greenAccent,
      Colors.lightGreenAccent,
      Colors.limeAccent,
      Colors.yellowAccent,
      Colors.amberAccent,
      Colors.orangeAccent,
      Colors.deepOrangeAccent,
    ],
    (primary, swatch) => MaterialAccentColor(primary.value, swatch),
  );
  static final primary = MaterialPalette<MaterialColor>.fromSwatches(
    const [50, 100, 200, 300, 400, 500, 600, 700, 800, 900],
    5,
    const <MaterialColor>[
      Colors.red,
      Colors.pink,
      Colors.purple,
      Colors.deepPurple,
      Colors.indigo,
      Colors.blue,
      Colors.lightBlue,
      Colors.cyan,
      Colors.teal,
      Colors.green,
      Colors.lightGreen,
      Colors.lime,
      Colors.yellow,
      Colors.amber,
      Colors.orange,
      Colors.deepOrange,
      Colors.brown,
      Colors.grey,
      Colors.blueGrey,
    ],
    (primary, swatch) => MaterialColor(primary.value, swatch),
  );
}
